@@ -1,12 +1,9 @@
 import datetime as dt
+
 from pandas import to_datetime
-from requests_file import FileAdapter
-from pandas_datareader.compat import is_number
-
 import requests
-import requests_ftp
 
-requests_ftp.monkeypatch_session()
+from pandas_datareader.compat import is_number
 
 
 class SymbolWarning(UserWarning):
@@ -19,9 +16,16 @@ class RemoteDataError(IOError):
 
 def _sanitize_dates(start, end):
     """
-    Return (datetime_start, datetime_end) tuple
-    if start is None - default is 2010/01/01
+    Return (timestamp_start, timestamp_end) tuple
+    if start is None - default is 5 years before the current date
     if end is None - default is today
+
+    Parameters
+    ----------
+    start : str, int, date, datetime, Timestamp
+        Desired start date
+    end : str, int, date, datetime, Timestamp
+        Desired end date
     """
     if is_number(start):
         # regard int as year
@@ -33,15 +37,24 @@ def _sanitize_dates(start, end):
     end = to_datetime(end)
 
     if start is None:
-        start = dt.datetime(2010, 1, 1)
+        # default to 5 years before today
+        today = dt.date.today()
+        start = today - dt.timedelta(days=365 * 5)
     if end is None:
-        end = dt.datetime.today()
+        # default to today
+        end = dt.date.today()
+    try:
+        start = to_datetime(start)
+        end = to_datetime(end)
+    except (TypeError, ValueError):
+        raise ValueError("Invalid date format.")
+    if start > end:
+        raise ValueError("start must be an earlier date than end")
     return start, end
 
 
 def _init_session(session, retry_count=3):
     if session is None:
         session = requests.Session()
-        session.mount('file://', FileAdapter())
         # do not set requests max_retries here to support arbitrary pause
     return session
