@@ -1,18 +1,17 @@
-import os
 from datetime import datetime
+import os
 
 import numpy as np
 import pandas as pd
-
-import pytest
 import pandas.util.testing as tm
+import pytest
 
 import pandas_datareader.data as web
 
 
 @pytest.yield_fixture
 def aapl():
-    aapl = web.Options('aapl', 'yahoo')
+    aapl = web.Options("aapl", "yahoo")
     yield aapl
     aapl.close()
 
@@ -51,18 +50,16 @@ def expiry(month, year):
 
 @pytest.fixture
 def json1(datapath):
-    dirpath = datapath('yahoo', 'data')
-    json1 = 'file://' + os.path.join(
-        dirpath, 'yahoo_options1.json')
+    dirpath = datapath("yahoo", "data")
+    json1 = "file://" + os.path.join(dirpath, "yahoo_options1.json")
     return json1
 
 
 @pytest.fixture
 def json2(datapath):
     # see gh-22: empty table
-    dirpath = datapath('yahoo', 'data')
-    json2 = 'file://' + os.path.join(
-        dirpath, 'yahoo_options2.json')
+    dirpath = datapath("yahoo", "data")
+    json2 = "file://" + os.path.join(dirpath, "yahoo_options2.json")
     return json2
 
 
@@ -72,9 +69,9 @@ def data1(aapl, json1):
 
 
 class TestYahooOptions(object):
-
+    @classmethod
     def setup_class(cls):
-        pytest.skip('Skip all Yahoo! tests.')
+        pytest.skip("Skip all Yahoo! tests.")
 
     def assert_option_result(self, df):
         """
@@ -83,16 +80,42 @@ class TestYahooOptions(object):
         assert isinstance(df, pd.DataFrame)
         assert len(df) > 1
 
-        exp_columns = pd.Index(['Last', 'Bid', 'Ask', 'Chg', 'PctChg', 'Vol',
-                                'Open_Int', 'IV', 'Root', 'IsNonstandard',
-                                'Underlying', 'Underlying_Price', 'Quote_Time',
-                                'Last_Trade_Date', 'JSON'])
+        exp_columns = pd.Index(
+            [
+                "Last",
+                "Bid",
+                "Ask",
+                "Chg",
+                "PctChg",
+                "Vol",
+                "Open_Int",
+                "IV",
+                "Root",
+                "IsNonstandard",
+                "Underlying",
+                "Underlying_Price",
+                "Quote_Time",
+                "Last_Trade_Date",
+                "JSON",
+            ]
+        )
         tm.assert_index_equal(df.columns, exp_columns)
-        assert df.index.names == [u'Strike', u'Expiry', u'Type', u'Symbol']
+        assert df.index.names == [u"Strike", u"Expiry", u"Type", u"Symbol"]
 
-        dtypes = [np.dtype(x) for x in ['float64'] * 7 +
-                  ['float64', 'object', 'bool', 'object', 'float64',
-                   'datetime64[ns]', 'datetime64[ns]', 'object']]
+        dtypes = [
+            np.dtype(x)
+            for x in ["float64"] * 7
+            + [
+                "float64",
+                "object",
+                "bool",
+                "object",
+                "float64",
+                "datetime64[ns]",
+                "datetime64[ns]",
+                "object",
+            ]
+        ]
         tm.assert_series_equal(df.dtypes, pd.Series(dtypes, index=exp_columns))
 
     def test_get_options_data(self, aapl, expiry):
@@ -107,25 +130,24 @@ class TestYahooOptions(object):
         self.assert_option_result(options)
 
     def test_get_near_stock_price(self, aapl, expiry):
-        options = aapl.get_near_stock_price(call=True, put=True,
-                                            expiry=expiry)
+        options = aapl.get_near_stock_price(call=True, put=True, expiry=expiry)
         self.assert_option_result(options)
 
     def test_options_is_not_none(self):
-        option = web.Options('aapl', 'yahoo')
+        option = web.Options("aapl", "yahoo")
         assert option is not None
 
     def test_get_call_data(self, aapl, expiry):
         calls = aapl.get_call_data(expiry=expiry)
 
         self.assert_option_result(calls)
-        assert calls.index.levels[2][0] == 'call'
+        assert calls.index.levels[2][0] == "call"
 
     def test_get_put_data(self, aapl, expiry):
         puts = aapl.get_put_data(expiry=expiry)
 
         self.assert_option_result(puts)
-        assert puts.index.levels[2][1] == 'put'
+        assert puts.index.levels[2][1] == "put"
 
     def test_get_expiry_dates(self, aapl):
         dates = aapl._get_expiry_dates()
@@ -151,7 +173,7 @@ class TestYahooOptions(object):
 
     def test_get_underlying_price(self, aapl):
         # see gh-7
-        options_object = web.Options('^spxpm', 'yahoo')
+        options_object = web.Options("^spxpm", "yahoo")
         quote_price = options_object.underlying_price
 
         assert isinstance(quote_price, float)
@@ -162,49 +184,44 @@ class TestYahooOptions(object):
         assert isinstance(price, (int, float, complex))
         assert isinstance(quote_time, (datetime, pd.Timestamp))
 
-    @pytest.mark.xfail(reason='Invalid URL scheme')
+    @pytest.mark.xfail(reason="Invalid URL scheme")
     def test_chop(self, aapl, data1):
         # gh-7625: regression test
-        aapl._chop_data(data1, above_below=2,
-                        underlying_price=np.nan)
-        chopped = aapl._chop_data(data1, above_below=2,
-                                  underlying_price=100)
+        aapl._chop_data(data1, above_below=2, underlying_price=np.nan)
+        chopped = aapl._chop_data(data1, above_below=2, underlying_price=100)
 
         assert isinstance(chopped, pd.DataFrame)
         assert len(chopped) > 1
 
-        chopped2 = aapl._chop_data(data1, above_below=2,
-                                   underlying_price=None)
+        chopped2 = aapl._chop_data(data1, above_below=2, underlying_price=None)
 
         assert isinstance(chopped2, pd.DataFrame)
         assert len(chopped2) > 1
 
-    @pytest.mark.xfail(reason='Invalid URL scheme')
+    @pytest.mark.xfail(reason="Invalid URL scheme")
     def test_chop_out_of_strike_range(self, aapl, data1):
         # gh-7625: regression test
-        aapl._chop_data(data1, above_below=2,
-                        underlying_price=np.nan)
-        chopped = aapl._chop_data(data1, above_below=2,
-                                  underlying_price=100000)
+        aapl._chop_data(data1, above_below=2, underlying_price=np.nan)
+        chopped = aapl._chop_data(data1, above_below=2, underlying_price=100000)
 
         assert isinstance(chopped, pd.DataFrame)
         assert len(chopped) > 1
 
-    @pytest.mark.xfail(reason='Invalid URL scheme')
+    @pytest.mark.xfail(reason="Invalid URL scheme")
     def test_sample_page_chg_float(self, data1):
         # Tests that numeric columns with comma's are appropriately dealt with
-        assert data1['Chg'].dtype == 'float64'
+        assert data1["Chg"].dtype == "float64"
 
     def test_month_year(self, aapl, month, year):
         # see gh-168
         data = aapl.get_call_data(month=month, year=year)
 
         assert len(data) > 1
-        assert data.index.levels[0].dtype == 'float64'
+        assert data.index.levels[0].dtype == "float64"
 
         self.assert_option_result(data)
 
-    @pytest.mark.xfail(reason='Invalid URL scheme')
+    @pytest.mark.xfail(reason="Invalid URL scheme")
     def test_empty_table(self, aapl, json2):
         # see gh-22
         empty = aapl._process_data(aapl._parse_url(json2))
