@@ -1,4 +1,6 @@
-from pandas import (concat, DataFrame, MultiIndex)
+from pandas import DataFrame, MultiIndex
+
+from pandas_datareader.compat import concat
 from pandas_datareader.yahoo.daily import YahooDailyReader
 
 
@@ -26,34 +28,34 @@ class YahooActionReader(YahooDailyReader):
 
 
 def _get_one_action(data):
-    actions = DataFrame(columns=['action', 'value'])
+    actions = DataFrame(columns=["action", "value"])
 
-    if 'Dividends' in data.columns:
+    if "Dividends" in data.columns:
         # Add a label column so we can combine our two DFs
-        dividends = DataFrame(data['Dividends']).dropna()
+        dividends = DataFrame(data["Dividends"]).dropna()
         dividends["action"] = "DIVIDEND"
-        dividends = dividends.rename(columns={'Dividends': 'value'})
-        actions = concat([actions, dividends]).sort_index(ascending=False)
+        dividends = dividends.rename(columns={"Dividends": "value"})
+        actions = concat([actions, dividends], sort=True)
+        actions = actions.sort_index(ascending=False)
 
-    if 'Splits' in data.columns:
+    if "Splits" in data.columns:
         # Add a label column so we can combine our two DFs
-        splits = DataFrame(data['Splits']).dropna()
+        splits = DataFrame(data["Splits"]).dropna()
         splits["action"] = "SPLIT"
-        splits = splits.rename(columns={'Splits': 'value'})
-        actions = concat([actions, splits]).sort_index(ascending=False)
+        splits = splits.rename(columns={"Splits": "value"})
+        actions = concat([actions, splits], sort=True)
+        actions = actions.sort_index(ascending=False)
 
     return actions
 
 
 class YahooDivReader(YahooActionReader):
-
     def read(self):
         data = super(YahooDivReader, self).read()
-        return data[data['action'] == 'DIVIDEND']
+        return data[data["action"] == "DIVIDEND"]
 
 
 class YahooSplitReader(YahooActionReader):
-
     def read(self):
         data = super(YahooSplitReader, self).read()
-        return data[data['action'] == 'SPLIT']
+        return data[data["action"] == "SPLIT"]
