@@ -1,14 +1,15 @@
-import json
 from collections import OrderedDict
+import json
+
 from pandas import DataFrame
 
 from pandas_datareader.base import _BaseReader
 from pandas_datareader.compat import string_types
 
 _DEFAULT_PARAMS = {
-    'lang': 'en-US',
-    'corsDomain': 'finance.yahoo.com',
-    '.tsrc': 'finance',
+    "lang": "en-US",
+    "corsDomain": "finance.yahoo.com",
+    ".tsrc": "finance",
 }
 
 
@@ -18,7 +19,7 @@ class YahooQuotesReader(_BaseReader):
 
     @property
     def url(self):
-        return 'https://query1.finance.yahoo.com/v7/finance/quote'
+        return "https://query1.finance.yahoo.com/v7/finance/quote"
 
     def read(self):
         if isinstance(self.symbols, string_types):
@@ -26,20 +27,20 @@ class YahooQuotesReader(_BaseReader):
         else:
             data = OrderedDict()
             for symbol in self.symbols:
-                data[symbol] = \
-                    self._read_one_data(
-                        self.url, self.params(symbol)).loc[symbol]
-            return DataFrame.from_dict(data, orient='index')
+                data[symbol] = self._read_one_data(self.url, self.params(symbol)).loc[
+                    symbol
+                ]
+            return DataFrame.from_dict(data, orient="index")
 
     def params(self, symbol):
         """Parameters to use in API calls"""
         # Construct the code request string.
-        params = {'symbols': symbol}
+        params = {"symbols": symbol}
         params.update(_DEFAULT_PARAMS)
         return params
 
     def _read_lines(self, out):
-        data = json.loads(out.read())['quoteResponse']['result'][0]
-        idx = data.pop('symbol')
-        data['price'] = data['regularMarketPrice']
+        data = json.loads(out.read())["quoteResponse"]["result"][0]
+        idx = data.pop("symbol")
+        data["price"] = data["regularMarketPrice"]
         return DataFrame(data, index=[idx])
